import espressomd
from espressomd.interactions import HarmonicBond
from espressomd.analyze import Analysis

box_l = 10.0 
bond_l = 1.0
bond_l_max = 2.0 # maximum bond length that I consider acceptable

system = espressomd.System(box_l=[box_l,box_l,box_l])
system.time_step = 0.01
system.cell_system.skin = 0.4
system.thermostat.set_langevin(kT=1.0, gamma=1.0, seed=1)

# set up a harmonic bond with length 1.0
my_bond = HarmonicBond(k=50.0, r_0=bond_l, r_cut = 2.0)
system.bonded_inter.add(my_bond)
        
# add first particle in the middle
system.part.add(id=0, pos=[box_l/2., box_l/2., box_l/2.])
print("part[0].pos:", system.part[0].pos)
# add second particle at bond_length from the first
system.part.add(id=1, pos=[box_l/2. + bond_l, box_l/2., box_l/2.])
# connect them with the bond
system.part[1].add_bond( (my_bond, 0) )
print("part[1].pos:", system.part[1].pos)
Rg=system.analysis.calc_rg(chain_start=0, number_of_chains=1, chain_length=2)
system.integrator.run(1)

# put the first particle back in the middle
system.part[0].pos=[box_l/2.,  box_l/2., box_l/2.]
print("part[0].pos:", system.part[0].pos)
# move second particle by box_length in the x-direction
system.part[1].pos=[box_l/2. + bond_l + box_l, box_l/2., box_l/2.]
print("part[1].pos:", system.part[1].pos)
print("Now, Espresso runs without an error")
# Espresso runs happily 
system.integrator.run(1)

# put the first particle back in the middle
system.part[0].pos=[box_l/2.,  box_l/2., box_l/2.]
print("part[0].pos:", system.part[0].pos)
# move second particle by non-integer multiple of box_l in the x-direction
system.part[1].pos=[box_l/2. + bond_l + 0.5*box_l, box_l/2., box_l/2.]
print("part[1].pos:", system.part[1].pos)
print("Now, Espresso reports an error: bond broken\n")
system.integrator.run(1)
# Espresso reports an error

